@@ -141,7 +141,7 @@ typedef struct myncb {
 /* one per virtual circuit */
 typedef struct smb_vc {
 	struct smb_vc *nextp;		/* not used */
-    int refCount;			/* the reference count */
+    unsigned long refCount;			/* the reference count */
     long flags;			/* the flags, if any; locked by mx */
     osi_mutex_t mx;			/* the mutex */
 	long vcID;			/* VC id */
@@ -153,7 +153,7 @@ typedef struct smb_vc {
     struct smb_user *usersp;	/* the first child in the user session list */
     struct smb_fid *fidsp;		/* the first child in the open file list */
 	struct smb_user *justLoggedOut;	/* ready for profile upload? */
-	unsigned long logoffTime;	/* tick count when logged off */
+	time_t logoffTime;	/* tick count when logged off */
 	/*struct cm_user *logonDLLUser;	/* integrated logon user */
 	unsigned char errorCount;
     char rname[17];
@@ -177,7 +177,7 @@ typedef struct smb_vc {
 /* one per user session */
 typedef struct smb_user {
 	struct smb_user *nextp;		/* next sibling */
-        long refCount;			/* ref count */
+        unsigned long refCount;			/* ref count */
         long flags;			/* flags; locked by mx */
         osi_mutex_t mx;
         long userID;			/* the session identifier */
@@ -187,7 +187,7 @@ typedef struct smb_user {
 
 typedef struct smb_username {
 	struct smb_username *nextp;		/* next sibling */
-        long refCount;			/* ref count */
+        unsigned long refCount;			/* ref count */
         long flags;			/* flags; locked by mx */
         osi_mutex_t mx;
 	struct cm_user *userp;		/* CM user structure */
@@ -202,7 +202,7 @@ typedef struct smb_username {
 /* one per tree-connect */
 typedef struct smb_tid {
 	struct smb_tid *nextp;		/* next sibling */
-        long refCount;
+        unsigned long refCount;
         long flags;
         osi_mutex_t mx;			/* for non-tree-related stuff */
         unsigned short tid;		/* the tid */
@@ -218,7 +218,7 @@ typedef struct smb_tid {
 /* one per process ID */
 typedef struct smb_pid {
 	struct smb_pid *nextp;		/* next sibling */
-        long refCount;
+        unsigned long refCount;
         long flags;
         osi_mutex_t mx;			/* for non-tree-related stuff */
         unsigned short pid;		/* the pid */
@@ -260,8 +260,8 @@ typedef struct smb_ioctl {
 /* one per file ID; these are really file descriptors */
 typedef struct smb_fid {
 	osi_queue_t q;
-        long refCount;
-        long flags;
+        unsigned long refCount;
+        unsigned long flags;
         osi_mutex_t mx;			/* for non-tree-related stuff */
         unsigned short fid;		/* the file ID */
         struct smb_vc *vcp;		/* back ptr */
@@ -313,10 +313,10 @@ typedef struct smb_fid {
 typedef struct smb_dirSearch {
 	osi_queue_t q;			/* queue of all outstanding cookies */
         osi_mutex_t mx;			/* just in case the caller screws up */
-        int refCount;			/* reference count */
+        unsigned long refCount;			/* reference count */
         long cookie;			/* value returned to the caller */
         struct cm_scache *scp;		/* vnode of the dir we're searching */
-        long lastTime;			/* last time we used this */
+        time_t lastTime;		/* last time we used this */
         long flags;			/* flags (see below);
 					 * locked by smb_globalLock */
         unsigned short attribute;	/* search attribute
@@ -339,8 +339,10 @@ typedef struct smb_dirListPatch {
 } smb_dirListPatch_t;
 
 /* dirListPatch Flags */
-#define SMB_DIRLISTPATCH_DOTFILE 1  /* the file referenced is a dot file 
-									   Note: will not be set if smb_hideDotFiles is false */
+#define SMB_DIRLISTPATCH_DOTFILE 1  
+/* the file referenced is a dot file
+ * Note: will not be set if smb_hideDotFiles is false 
+ */
 
 /* waiting lock list elements */
 typedef struct smb_waitingLock {
@@ -348,7 +350,7 @@ typedef struct smb_waitingLock {
 	smb_vc_t *vcp;
 	smb_packet_t *inp;
 	smb_packet_t *outp;
-	u_long timeRemaining;
+	time_t timeRemaining;
 	void *lockp;
 } smb_waitingLock_t;
 
@@ -378,17 +380,17 @@ extern void smb_Init(osi_log_t *logp, char *smbNamep, int useV3, int LANadapt,
 #endif
   );
 
-extern void smb_LargeSearchTimeFromUnixTime(FILETIME *largeTimep, afs_uint32 unixTime);
+extern void smb_LargeSearchTimeFromUnixTime(FILETIME *largeTimep, time_t unixTime);
 
-extern void smb_UnixTimeFromLargeSearchTime(afs_uint32 *unixTimep, FILETIME *largeTimep);
+extern void smb_UnixTimeFromLargeSearchTime(time_t *unixTimep, FILETIME *largeTimep);
 
-extern void smb_SearchTimeFromUnixTime(long *dosTimep, afs_uint32 unixTime);
+extern void smb_SearchTimeFromUnixTime(time_t *dosTimep, time_t unixTime);
 
-extern void smb_UnixTimeFromSearchTime(afs_uint32 *unixTimep, long searchTime);
+extern void smb_UnixTimeFromSearchTime(time_t *unixTimep, time_t searchTime);
 
-extern void smb_DosUTimeFromUnixTime(afs_uint32 *dosUTimep, afs_uint32 unixTime);
+extern void smb_DosUTimeFromUnixTime(time_t *dosUTimep, time_t unixTime);
 
-extern void smb_UnixTimeFromDosUTime(afs_uint32 *unixTimep, afs_uint32 dosUTime);
+extern void smb_UnixTimeFromDosUTime(time_t *unixTimep, time_t dosUTime);
 
 extern smb_vc_t *smb_FindVC(unsigned short lsn, int flags, int lana);
 
@@ -474,7 +476,7 @@ extern void smb_HoldVC(smb_vc_t *vcp);
 /* some globals, too */
 extern char *smb_localNamep;
 extern int loggedOut;
-extern unsigned long loggedOutTime;
+extern time_t loggedOutTime;
 extern char *loggedOutName;
 extern smb_user_t *loggedOutUserp;
 
@@ -485,7 +487,7 @@ extern osi_rwlock_t smb_globalLock;
 extern osi_rwlock_t smb_rctLock;
 
 extern int smb_LogoffTokenTransfer;
-extern unsigned long smb_LogoffTransferTimeout;
+extern time_t smb_LogoffTransferTimeout;
 
 extern int smb_maxVCPerServer; /* max # of VCs per server */
 extern int smb_maxMpxRequests; /* max # of mpx requests */
@@ -559,6 +561,10 @@ extern long smb_ReadData(smb_fid_t *fidp, osi_hyper_t *offsetp, long count,
 	char *op, cm_user_t *userp, long *readp, int dosflag);
 #endif /* !DJGPP */
 
+extern long smb_Rename(smb_vc_t *vcp, smb_packet_t *inp, char *oldPathp, char *newPathp, int attrs);
+
+extern long smb_Link(smb_vc_t *vcp, smb_packet_t *inp, char *oldPathp, char *newPathp);
+
 extern BOOL smb_IsLegalFilename(char *filename);
 
 extern char *smb_GetSharename(void);
