@@ -21,7 +21,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_dirops.c,v 1.14 2003/08/29 22:00:04 rees Exp $");
+    ("$Header: /cvs/openafs/src/afs/VNOPS/afs_vnop_dirops.c,v 1.14.2.2 2004/10/18 17:43:51 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -47,7 +47,7 @@ afs_mkdir(ndp, attrs)
     struct ucred *acred = ndp->ni_cred;
 #else /* AFS_OSF_ENV */
 afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
-    OSI_VC_DECL(adp);
+     OSI_VC_DECL(adp);
      register struct vcache **avcp;
      char *aname;
      struct vattr *attrs;
@@ -67,9 +67,10 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
     struct AFSVolSync tsync;
     afs_int32 now;
     struct afs_fakestat_state fakestate;
-    XSTATS_DECLS OSI_VC_CONVERT(adp)
+    XSTATS_DECLS;
+    OSI_VC_CONVERT(adp);
 
-      AFS_STATCNT(afs_mkdir);
+    AFS_STATCNT(afs_mkdir);
     afs_Trace2(afs_iclSetp, CM_TRACE_MKDIR, ICL_TYPE_POINTER, adp,
 	       ICL_TYPE_STRING, aname);
 
@@ -146,10 +147,10 @@ afs_mkdir(OSI_VC_ARG(adp), aname, attrs, avcp, acred)
 	ObtainWriteLock(&tdc->lock, 632);
     if (afs_LocalHero(adp, tdc, &OutDirStatus, 1)) {
 	/* we can do it locally */
-	code = afs_dir_Create(&tdc->f.inode, aname, &newFid.Fid);
+	code = afs_dir_Create(&tdc->f, aname, &newFid.Fid);
 	if (code) {
 	    ZapDCE(tdc);	/* surprise error -- use invalid value */
-	    DZap(&tdc->f.inode);
+	    DZap(&tdc->f);
 	}
     }
     if (tdc) {
@@ -194,7 +195,7 @@ afs_rmdir(OSI_VC_ARG(adp), aname, cdirp, acred)
 #else
 afs_rmdir(adp, aname, acred)
 #endif
-    OSI_VC_DECL(adp);
+     OSI_VC_DECL(adp);
      char *aname;
      struct AFS_UCRED *acred;
 {
@@ -208,9 +209,10 @@ afs_rmdir(adp, aname, acred)
     struct AFSFetchStatus OutDirStatus;
     struct AFSVolSync tsync;
     struct afs_fakestat_state fakestate;
-    XSTATS_DECLS OSI_VC_CONVERT(adp)
+    XSTATS_DECLS;
+    OSI_VC_CONVERT(adp);
 
-      AFS_STATCNT(afs_rmdir);
+    AFS_STATCNT(afs_rmdir);
 
     afs_Trace2(afs_iclSetp, CM_TRACE_RMDIR, ICL_TYPE_POINTER, adp,
 	       ICL_TYPE_STRING, aname);
@@ -248,7 +250,7 @@ afs_rmdir(adp, aname, acred)
 	struct VenusFid unlinkFid;
 
 	unlinkFid.Fid.Vnode = 0;
-	code = afs_dir_Lookup(&tdc->f.inode, aname, &unlinkFid.Fid);
+	code = afs_dir_Lookup(&tdc->f, aname, &unlinkFid.Fid);
 	if (code == 0) {
 	    afs_int32 cached = 0;
 
@@ -302,10 +304,10 @@ afs_rmdir(adp, aname, acred)
 	UpgradeSToWLock(&tdc->lock, 634);
     if (afs_LocalHero(adp, tdc, &OutDirStatus, 1)) {
 	/* we can do it locally */
-	code = afs_dir_Delete(&tdc->f.inode, aname);
+	code = afs_dir_Delete(&tdc->f, aname);
 	if (code) {
 	    ZapDCE(tdc);	/* surprise error -- invalid value */
-	    DZap(&tdc->f.inode);
+	    DZap(&tdc->f);
 	}
     }
     if (tdc) {
